@@ -25,19 +25,25 @@
 
 #include <config.h>
 
+#ifndef GNOME_DISABLE_DEPRECATED_SOURCE
+
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
 #include <glib/gi18n-lib.h>
+
+#undef GTK_DISABLE_DEPRECATED /* for GtkOptionMenu */
 #include <gtk/gtk.h>
 
 #include <libgnome/gnome-macros.h>
 
 #include <libgnomeui/gnome-uidefs.h>
-#include <libgnomeui/gnome-icon-entry.h>
 
 #include <libgnomevfs/gnome-vfs-utils.h>
 
+#undef GNOME_DISABLE_DEPRECATED
+#include <libgnomeui/gnome-icon-entry.h>
+
 #include <libgnome/gnome-desktop-item.h>
 #include <libgnomeui/gnome-ditem-edit.h>
 
@@ -82,7 +88,6 @@ struct _GnomeDItemEditPrivate {
 };
 
 static void gnome_ditem_edit_class_init   (GnomeDItemEditClass *klass);
-static void gnome_ditem_edit_instance_init(GnomeDItemEdit      *dee);
 
 static void gnome_ditem_edit_destroy      (GtkObject           *object);
 static void gnome_ditem_edit_finalize     (GObject             *object);
@@ -94,10 +99,6 @@ static void gnome_ditem_edit_changed      (GnomeDItemEdit      *dee);
 static void gnome_ditem_edit_icon_changed (GnomeDItemEdit      *dee);
 static void gnome_ditem_edit_name_changed (GnomeDItemEdit      *dee);
 
-static void destroy_tooltip (GtkObject *object);
-static void set_tooltip (GnomeDItemEdit *dee, GtkWidget *widget,
-			 const gchar *description);
-
 enum {
         CHANGED,
         ICON_CHANGED,
@@ -109,10 +110,7 @@ static gint ditem_edit_signals[LAST_SIGNAL] = { 0 };
 
 /* The following defines the get_type */
 
-GNOME_CLASS_BOILERPLATE (GnomeDItemEdit, gnome_ditem_edit,
-			 GtkNotebook, GTK_TYPE_NOTEBOOK)
-
-
+G_DEFINE_TYPE(GnomeDItemEdit, gnome_ditem_edit, GTK_TYPE_NOTEBOOK)
 
 static void
 gnome_ditem_edit_class_init (GnomeDItemEditClass *klass)
@@ -700,6 +698,7 @@ make_advanced_page (GnomeDItemEdit *dee)
 	GtkWidget *entry;
 	GtkWidget *button;
 	GtkWidget *box;
+	char      *markup;
 
 	vbox = gtk_vbox_new (FALSE, 6);
         gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
@@ -758,21 +757,27 @@ make_advanced_page (GnomeDItemEdit *dee)
 	gtk_widget_set_size_request (entry, 30, -1);
 	dee->_priv->transl_lang_entry = entry;
 
-	set_tooltip (dee, GTK_WIDGET(entry), _("Language"));
+	markup = g_markup_escape_text (_("Language"), -1);
+	g_object_set (entry, "tooltip-markup", markup, NULL);
+	g_free (markup);
 
 	entry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (box), entry, TRUE, TRUE, 0);
 	gtk_widget_set_size_request (entry, 80, -1);
 	dee->_priv->transl_name_entry = entry;
 
-	set_tooltip (dee, GTK_WIDGET(entry), _("Name"));
+	markup = g_markup_escape_text (_("Name"), -1);
+	g_object_set (entry, "tooltip-markup", markup, NULL);
+	g_free (markup);
 
 	entry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (box), entry, TRUE, TRUE, 0);
 	gtk_widget_set_size_request (entry, 80, -1);
 	dee->_priv->transl_generic_name_entry = entry;
 
-	set_tooltip (dee, GTK_WIDGET (entry), _("Generic name"));
+	markup = g_markup_escape_text (_("Generic name"), -1);
+	g_object_set (entry, "tooltip-markup", markup, NULL);
+	g_free (markup);
 
 	/* FIXME: transl_icon_entry, locale specific icons */
 
@@ -781,28 +786,35 @@ make_advanced_page (GnomeDItemEdit *dee)
 	gtk_widget_set_size_request (entry, 80, -1);
 	dee->_priv->transl_comment_entry = entry;
 
-	set_tooltip (dee, GTK_WIDGET(entry), _("Comment"));
+	markup = g_markup_escape_text (_("Comment"), -1);
+	g_object_set (entry, "tooltip-markup", markup, NULL);
+	g_free (markup);
 
 	button = gtk_button_new_with_mnemonic (_("_Add/Set"));
 	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 0);
 	g_signal_connect (button, "clicked",
 			  G_CALLBACK (translations_add), dee);
   
-	set_tooltip (dee, GTK_WIDGET(button),
-		    _("Add or Set Name/Comment Translations"));
+	markup = g_markup_escape_text (_("Add or Set Name/Comment Translations"),
+				       -1);
+	g_object_set (button, "tooltip-markup", markup, NULL);
+	g_free (markup);
 
 	button = gtk_button_new_with_mnemonic (_("Re_move"));
 	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 0);
 	g_signal_connect (button, "clicked",
 			  G_CALLBACK (translations_remove), dee);
-	set_tooltip (dee, GTK_WIDGET(button),
-		    _("Remove Name/Comment Translation"));
+
+	markup = g_markup_escape_text (_("Remove Name/Comment Translation"),
+				       -1);
+	g_object_set (button, "tooltip-markup", markup, NULL);
+	g_free (markup);
   
 	return vbox;
 }
 
 static void
-gnome_ditem_edit_instance_init (GnomeDItemEdit *dee)
+gnome_ditem_edit_init (GnomeDItemEdit *dee)
 {
 	GtkWidget *page;
 
@@ -834,6 +846,8 @@ gnome_ditem_edit_instance_init (GnomeDItemEdit *dee)
  * for the purpose of editing #GnomeDesktopItems
  *
  * Returns: Newly-created #GnomeDItemEdit widget.
+ *
+ * Deprecated: 2.18:
  */
 GtkWidget *
 gnome_ditem_edit_new (void)
@@ -861,9 +875,7 @@ gnome_ditem_edit_destroy (GtkObject *object)
 		gnome_desktop_item_unref (de->_priv->ditem);
 	de->_priv->ditem = NULL; /* just for sanity */
 
-	destroy_tooltip (object);
-
-	GNOME_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	GTK_OBJECT_CLASS (gnome_ditem_edit_parent_class)->destroy (object);
 }
 
 static void
@@ -879,7 +891,7 @@ gnome_ditem_edit_finalize (GObject *object)
 	g_free(de->_priv);
 	de->_priv = NULL;
 
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
+	G_OBJECT_CLASS (gnome_ditem_edit_parent_class)->finalize (object);
 }
 
 /* set sensitive for directory/other type of a ditem */
@@ -1212,6 +1224,8 @@ gnome_ditem_edit_sync_ditem (GnomeDItemEdit *dee)
  * of the object accordingly.
  *
  * Returns:  %TRUE if successful, %FALSE otherwise
+ *
+ * Deprecated: 2.18:
  */
 gboolean
 gnome_ditem_edit_load_uri (GnomeDItemEdit *dee,
@@ -1249,6 +1263,8 @@ gnome_ditem_edit_load_uri (GnomeDItemEdit *dee,
  * internally so do not worry about modifying this item later yourself.
  * Note that since the entire item is stored, any hidden fields will be
  * preserved when you later get it with #gnome_ditem_edit_get_ditem.
+ *
+ * Deprecated: 2.18:
  */
 void
 gnome_ditem_edit_set_ditem (GnomeDItemEdit *dee,
@@ -1277,6 +1293,8 @@ gnome_ditem_edit_set_ditem (GnomeDItemEdit *dee,
  * make a copy of it with #gnome_desktop_item_copy
  *
  * Returns: a pointer to the internal #GnomeDesktopItem structure.
+ *
+ * Deprecated: 2.18:
  */
 GnomeDesktopItem *
 gnome_ditem_edit_get_ditem (GnomeDItemEdit *dee)
@@ -1301,6 +1319,8 @@ gnome_ditem_edit_get_ditem (GnomeDItemEdit *dee)
  *
  * Description: Clear the editting areas.  And unref any
  * stored #GnomeDesktopItem.
+ *
+ * Deprecated: 2.18:
  */
 void
 gnome_ditem_edit_clear (GnomeDItemEdit *dee)
@@ -1362,6 +1382,8 @@ gnome_ditem_edit_name_changed (GnomeDItemEdit *dee)
  * Description: Get the icon filename.
  *
  * Returns: a newly allocated string with the filename of the icon
+ *
+ * Deprecated: 2.18:
  */
 gchar *
 gnome_ditem_edit_get_icon (GnomeDItemEdit *dee)
@@ -1379,6 +1401,8 @@ gnome_ditem_edit_get_icon (GnomeDItemEdit *dee)
  * Description: Get the Name field from the ditem for the current language.
  *
  * Returns: a newly allocated string with the name of the ditem
+ *
+ * Deprecated: 2.18:
  */
 gchar *
 gnome_ditem_edit_get_name (GnomeDItemEdit *dee)
@@ -1393,6 +1417,14 @@ gnome_ditem_edit_get_name (GnomeDItemEdit *dee)
 }
 
 /* eeeeeeeeek!, evil api */
+/**
+ * gnome_ditem_edit_grab_focus
+ * @dee: #GnomeDItemEdit object to work with
+ *
+ * Description: Give the focus to the editor.
+ *
+ * Deprecated: 2.18:
+ */
 void
 gnome_ditem_edit_grab_focus (GnomeDItemEdit *dee)
 {
@@ -1401,6 +1433,16 @@ gnome_ditem_edit_grab_focus (GnomeDItemEdit *dee)
 
 	gtk_widget_grab_focus (dee->_priv->name_entry);
 }
+
+/**
+ * gnome_ditem_edit_set_editable
+ * @dee: #GnomeDItemEdit object to work with
+ * @editable: %TRUE to set the object editable
+ *
+ * Description: Set the object editable.
+ *
+ * Deprecated: 2.18:
+ */
 void
 gnome_ditem_edit_set_editable (GnomeDItemEdit *dee,
 			       gboolean editable)
@@ -1413,7 +1455,15 @@ gnome_ditem_edit_set_editable (GnomeDItemEdit *dee,
 	gtk_widget_set_sensitive (dee->_priv->child2, editable);
 }
 
-/* set the string type of the entry */
+/**
+ * gnome_ditem_edit_set_entry_type
+ * @dee: #GnomeDItemEdit object to work with
+ * @type: a type
+ *
+ * Description: Set the string type of the entry.
+ *
+ * Deprecated: 2.18:
+ */
 void
 gnome_ditem_edit_set_entry_type (GnomeDItemEdit *dee,
 				 const char     *type)
@@ -1440,7 +1490,15 @@ gnome_ditem_edit_set_entry_type (GnomeDItemEdit *dee,
 	}
 }
 
-/* force directory only */
+/**
+ * gnome_ditem_edit_set_entry_type
+ * @dee: #GnomeDItemEdit object to work with
+ * @directory_only: %TRUE to force directory only
+ *
+ * Description: Force directory only.
+ *
+ * Deprecated: 2.18:
+ */
 void
 gnome_ditem_edit_set_directory_only (GnomeDItemEdit *dee,
 				     gboolean        directory_only)
@@ -1475,42 +1533,4 @@ gnome_ditem_edit_set_directory_only (GnomeDItemEdit *dee,
 	}
 }
 
-static void
-destroy_tooltip (GtkObject *object)
-{
-	GtkTooltips *tooltips;
-
-	tooltips = g_object_get_data (G_OBJECT (object), "tooltips");
-	if (tooltips) {
-		g_object_unref (tooltips);
-		g_object_set_data (G_OBJECT (object), "tooltips", NULL);
-	}
-}
-
-/**
- * set_tooltip
- * @dee: #GnomeDItemEdit object to work with
- * @widget: the GtkWidget you wish to associate the tip with.
- * @description: a string containing the tip itself.
- *
- * Description : Set @description as the tooltip for the @widget.
- *		 Creates the GtkTooltips structure if not already present.
- */
-static void
-set_tooltip (GnomeDItemEdit *dee, GtkWidget *widget, const gchar *description)
-{
-        GtkTooltips *tooltips;
-
-	tooltips = g_object_get_data (G_OBJECT (dee), "tooltips");
-
-	/* create if not already present */
-	if (!tooltips) {
-		tooltips = gtk_tooltips_new ();
-		g_return_if_fail (tooltips != NULL);
-		g_object_ref (tooltips);
-		gtk_object_sink (GTK_OBJECT (tooltips));
-		g_object_set_data (G_OBJECT (dee), "tooltips", tooltips);
-	}
-
-        gtk_tooltips_set_tip (tooltips, widget, description, NULL);
-}
+#endif /* GNOME_DISABLE_DEPRECATED_SOURCE */
